@@ -36,8 +36,4 @@ class ArticlePool(Resource):
         result = {"thread_id": thread_id}
         return result, 200, {'Content-Type': 'application/json'}
 
-    @staticmethod
-    def delete(thread_id):
-        global exporting_threads
-        exporting_threads.pop(thread_id)
-        return {}, 200, {'Content-Type': 'application/json'}
+
