@@ -36,3 +36,8 @@ class ArticleProgress(Resource):
             "html": article.html
         }
         return response, 200, {'Content-Type': 'application/json'}
+
+    @staticmethod
+    def delete(thread_id):
+        exporting_threads.pop(thread_id)
+        return {}, 200, {'Content-Type': 'application/json'}
